from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Method:
	"""Method commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("method", core, parent)

	def set(self, method: enums.CmMethUp, mobileStation=repcap.MobileStation.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation<ST>:CMODe:METHod \n
		Snippet: driver.source.bb.w3Gpp.mstation.cmode.method.set(method = enums.CmMethUp.HLSCheduling, mobileStation = repcap.MobileStation.Default) \n
		The command selects compressed mode method. \n
			:param method: HLSCheduling| SF2 SF2 The data is compressed by halving the spreading factor. HLSCheduling The data is compressed by stopping the transmission of the data stream during the transmission gap.
			:param mobileStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mstation')"""
		param = Conversions.enum_scalar_to_str(method, enums.CmMethUp)
		mobileStation_cmd_val = self._base.get_repcap_cmd_value(mobileStation, repcap.MobileStation)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:MSTation{mobileStation_cmd_val}:CMODe:METHod {param}')

	# noinspection PyTypeChecker
	def get(self, mobileStation=repcap.MobileStation.Default) -> enums.CmMethUp:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation<ST>:CMODe:METHod \n
		Snippet: value: enums.CmMethUp = driver.source.bb.w3Gpp.mstation.cmode.method.get(mobileStation = repcap.MobileStation.Default) \n
		The command selects compressed mode method. \n
			:param mobileStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mstation')
			:return: method: HLSCheduling| SF2 SF2 The data is compressed by halving the spreading factor. HLSCheduling The data is compressed by stopping the transmission of the data stream during the transmission gap."""
		mobileStation_cmd_val = self._base.get_repcap_cmd_value(mobileStation, repcap.MobileStation)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:W3GPp:MSTation{mobileStation_cmd_val}:CMODe:METHod?')
		return Conversions.str_to_scalar_enum(response, enums.CmMethUp)



from typing import List

from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Rsv:
	"""Rsv commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rsv", core, parent)

	def set(self, reserved: List[str], frameBlock=repcap.FrameBlock.Default, userIx=repcap.UserIx.Default, triggerFrameUser=repcap.TriggerFrameUser.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:[USER<DI>]:TFConfig:UINFo<ST0>:RSV \n
		Snippet: driver.source.bb.wlnn.fblock.user.tfConfig.uinfo.rsv.set(reserved = ['raw1', 'raw2', 'raw3'], frameBlock = repcap.FrameBlock.Default, userIx = repcap.UserIx.Default, triggerFrameUser = repcap.TriggerFrameUser.Default) \n
		Sets the value bits of the user info field. You can configure the user info for up to 37 users with the command
		[:SOURce<hw>]:BB:WLNN:FBLock<ch>[:USER<di>]:TFConfig:NUINfo. \n
			:param reserved: 7 bits
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:param triggerFrameUser: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Uinfo')"""
		param = Conversions.list_to_csv_str(reserved)
		frameBlock_cmd_val = self._base.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		userIx_cmd_val = self._base.get_repcap_cmd_value(userIx, repcap.UserIx)
		triggerFrameUser_cmd_val = self._base.get_repcap_cmd_value(triggerFrameUser, repcap.TriggerFrameUser)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:USER{userIx_cmd_val}:TFConfig:UINFo{triggerFrameUser_cmd_val}:RSV {param}')

	def get(self, frameBlock=repcap.FrameBlock.Default, userIx=repcap.UserIx.Default, triggerFrameUser=repcap.TriggerFrameUser.Default) -> List[str]:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:[USER<DI>]:TFConfig:UINFo<ST0>:RSV \n
		Snippet: value: List[str] = driver.source.bb.wlnn.fblock.user.tfConfig.uinfo.rsv.get(frameBlock = repcap.FrameBlock.Default, userIx = repcap.UserIx.Default, triggerFrameUser = repcap.TriggerFrameUser.Default) \n
		Sets the value bits of the user info field. You can configure the user info for up to 37 users with the command
		[:SOURce<hw>]:BB:WLNN:FBLock<ch>[:USER<di>]:TFConfig:NUINfo. \n
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:param triggerFrameUser: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Uinfo')
			:return: reserved: No help available"""
		frameBlock_cmd_val = self._base.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		userIx_cmd_val = self._base.get_repcap_cmd_value(userIx, repcap.UserIx)
		triggerFrameUser_cmd_val = self._base.get_repcap_cmd_value(triggerFrameUser, repcap.TriggerFrameUser)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:USER{userIx_cmd_val}:TFConfig:UINFo{triggerFrameUser_cmd_val}:RSV?')
		return Conversions.str_to_str_list(response)



from typing import List

from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Tcmd:
	"""Tcmd commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("tcmd", core, parent)

	def set(self, tpc_cmd_3: List[str], allocationNull=repcap.AllocationNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:DCI:ALLoc<CH0>:TCMD \n
		Snippet: driver.source.bb.eutra.downlink.emtc.dci.alloc.tcmd.set(tpc_cmd_3 = ['raw1', 'raw2', 'raw3'], allocationNull = repcap.AllocationNull.Default) \n
		Sets the TCP command field of the DCI format 3/3A. \n
			:param tpc_cmd_3: 64 bits
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')"""
		param = Conversions.list_to_csv_str(tpc_cmd_3)
		allocationNull_cmd_val = self._base.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:EMTC:DCI:ALLoc{allocationNull_cmd_val}:TCMD {param}')

	def get(self, allocationNull=repcap.AllocationNull.Default) -> List[str]:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:DCI:ALLoc<CH0>:TCMD \n
		Snippet: value: List[str] = driver.source.bb.eutra.downlink.emtc.dci.alloc.tcmd.get(allocationNull = repcap.AllocationNull.Default) \n
		Sets the TCP command field of the DCI format 3/3A. \n
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
			:return: tpc_cmd_3: 64 bits"""
		allocationNull_cmd_val = self._base.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:DL:EMTC:DCI:ALLoc{allocationNull_cmd_val}:TCMD?')
		return Conversions.str_to_str_list(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BbOnly:
	"""BbOnly commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("bbOnly", core, parent)

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:DM:PRAMp:BBONly:[STATe] \n
		Snippet: value: bool = driver.source.bb.dm.pramp.bbOnly.get_state() \n
		Enables power ramping in the baseband only or mixed power ramping in the baseband and the RF section. The ON setting is
		mandatory if, with power ramping active, only the baseband signal is output (I/Q outputs) . In case of two-path
		instruments, the ON setting is also mandatory if a baseband signal is applied to both paths. Only then can a signal with
		a defined, predictable level be output. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DM:PRAMp:BBONly:STATe?')
		return Conversions.str_to_bool(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Slevel:
	"""Slevel commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("slevel", core, parent)

	def set(self, slevel: enums.TetraSlotLevel, testMode=repcap.TestMode.Default, slot=repcap.Slot.Default, channel=repcap.Channel.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:TETRa:SCONfiguration:TMODe<DI>:SLOT<ST>:LDIRection<CH>:SLEVel \n
		Snippet: driver.source.bb.tetra.sconfiguration.tmode.slot.ldirection.slevel.set(slevel = enums.TetraSlotLevel.ATTenuated, testMode = repcap.TestMode.Default, slot = repcap.Slot.Default, channel = repcap.Channel.Default) \n
		Sets the level for the selected slot. \n
			:param slevel: OFF| ATTenuated| FULL OFF Attenuation is maximum. The slot is inactive. ATT Level is reduced by the level attenuation set in 'Slot Attenuation'. FULL The level corresponds to the level indicated in the display.
			:param testMode: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Tmode')
			:param slot: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Slot')
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ldirection')"""
		param = Conversions.enum_scalar_to_str(slevel, enums.TetraSlotLevel)
		testMode_cmd_val = self._base.get_repcap_cmd_value(testMode, repcap.TestMode)
		slot_cmd_val = self._base.get_repcap_cmd_value(slot, repcap.Slot)
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SOURce<HwInstance>:BB:TETRa:SCONfiguration:TMODe{testMode_cmd_val}:SLOT{slot_cmd_val}:LDIRection{channel_cmd_val}:SLEVel {param}')

	# noinspection PyTypeChecker
	def get(self, testMode=repcap.TestMode.Default, slot=repcap.Slot.Default, channel=repcap.Channel.Default) -> enums.TetraSlotLevel:
		"""SCPI: [SOURce<HW>]:BB:TETRa:SCONfiguration:TMODe<DI>:SLOT<ST>:LDIRection<CH>:SLEVel \n
		Snippet: value: enums.TetraSlotLevel = driver.source.bb.tetra.sconfiguration.tmode.slot.ldirection.slevel.get(testMode = repcap.TestMode.Default, slot = repcap.Slot.Default, channel = repcap.Channel.Default) \n
		Sets the level for the selected slot. \n
			:param testMode: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Tmode')
			:param slot: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Slot')
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ldirection')
			:return: slevel: OFF| ATTenuated| FULL OFF Attenuation is maximum. The slot is inactive. ATT Level is reduced by the level attenuation set in 'Slot Attenuation'. FULL The level corresponds to the level indicated in the display."""
		testMode_cmd_val = self._base.get_repcap_cmd_value(testMode, repcap.TestMode)
		slot_cmd_val = self._base.get_repcap_cmd_value(slot, repcap.Slot)
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:TETRa:SCONfiguration:TMODe{testMode_cmd_val}:SLOT{slot_cmd_val}:LDIRection{channel_cmd_val}:SLEVel?')
		return Conversions.str_to_scalar_enum(response, enums.TetraSlotLevel)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Execute:
	"""Execute commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("execute", core, parent)

	def set(self) -> None:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:COPY:EXECute \n
		Snippet: driver.source.bb.tdscdma.copy.execute.set() \n
		Starts the copy process. The dataset of the selected source cell is copied to the destination cell. \n
		"""
		self._core.io.write(f'SOURce<HwInstance>:BB:TDSCdma:COPY:EXECute')

	def set_with_opc(self) -> None:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:COPY:EXECute \n
		Snippet: driver.source.bb.tdscdma.copy.execute.set_with_opc() \n
		Starts the copy process. The dataset of the selected source cell is copied to the destination cell. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsSmw.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:BB:TDSCdma:COPY:EXECute')



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from .........Internal.Utilities import trim_str_response
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Dselection:
	"""Dselection commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("dselection", core, parent)

	def set(self, filename: str, terminal=repcap.Terminal.Default, packet=repcap.Packet.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EVDO:TERMinal<ST>:DCHannel:PACKet<CH>:DATA:DSELection \n
		Snippet: driver.source.bb.evdo.terminal.dchannel.packet.data.dselection.set(filename = '1', terminal = repcap.Terminal.Default, packet = repcap.Packet.Default) \n
		(enabled for an access terminal working in traffic mode) Selects the data list for the data source. \n
			:param filename: string
			:param terminal: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Terminal')
			:param packet: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Packet')"""
		param = Conversions.value_to_quoted_str(filename)
		terminal_cmd_val = self._base.get_repcap_cmd_value(terminal, repcap.Terminal)
		packet_cmd_val = self._base.get_repcap_cmd_value(packet, repcap.Packet)
		self._core.io.write(f'SOURce<HwInstance>:BB:EVDO:TERMinal{terminal_cmd_val}:DCHannel:PACKet{packet_cmd_val}:DATA:DSELection {param}')

	def get(self, terminal=repcap.Terminal.Default, packet=repcap.Packet.Default) -> str:
		"""SCPI: [SOURce<HW>]:BB:EVDO:TERMinal<ST>:DCHannel:PACKet<CH>:DATA:DSELection \n
		Snippet: value: str = driver.source.bb.evdo.terminal.dchannel.packet.data.dselection.get(terminal = repcap.Terminal.Default, packet = repcap.Packet.Default) \n
		(enabled for an access terminal working in traffic mode) Selects the data list for the data source. \n
			:param terminal: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Terminal')
			:param packet: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Packet')
			:return: filename: string"""
		terminal_cmd_val = self._base.get_repcap_cmd_value(terminal, repcap.Terminal)
		packet_cmd_val = self._base.get_repcap_cmd_value(packet, repcap.Packet)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EVDO:TERMinal{terminal_cmd_val}:DCHannel:PACKet{packet_cmd_val}:DATA:DSELection?')
		return trim_str_response(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class General:
	"""General commands group definition. 16 total commands, 1 Sub-groups, 9 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("general", core, parent)

	@property
	def es(self):
		"""es commands group. 2 Sub-classes, 5 commands."""
		if not hasattr(self, '_es'):
			from .Es import Es
			self._es = Es(self._core, self._base)
		return self._es

	# noinspection PyTypeChecker
	def get_cardeply(self) -> enums.Nr5GcarDep:
		"""SCPI: [SOURce<HW>]:BB:NR5G:QCKSet:GENeral:CARDeply \n
		Snippet: value: enums.Nr5GcarDep = driver.source.bb.nr5G.qckset.general.get_cardeply() \n
		Selects one of the frequency ranges, specified for 5G NR transmission. \n
			:return: qck_set_car_deply: FR1LT3| FR1GT3| FR2
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:QCKSet:GENeral:CARDeply?')
		return Conversions.str_to_scalar_enum(response, enums.Nr5GcarDep)

	def set_cardeply(self, qck_set_car_deply: enums.Nr5GcarDep) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:QCKSet:GENeral:CARDeply \n
		Snippet: driver.source.bb.nr5G.qckset.general.set_cardeply(qck_set_car_deply = enums.Nr5GcarDep.BT36) \n
		Selects one of the frequency ranges, specified for 5G NR transmission. \n
			:param qck_set_car_deply: FR1LT3| FR1GT3| FR2
		"""
		param = Conversions.enum_scalar_to_str(qck_set_car_deply, enums.Nr5GcarDep)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:QCKSet:GENeral:CARDeply {param}')

	# noinspection PyTypeChecker
	def get_cbw(self) -> enums.Nr5Gcbw:
		"""SCPI: [SOURce<HW>]:BB:NR5G:QCKSet:GENeral:CBW \n
		Snippet: value: enums.Nr5Gcbw = driver.source.bb.nr5G.qckset.general.get_cbw() \n
		Selects the bandwidth of the node carrier. \n
			:return: qck_set_channel_bw: BW5| BW10| BW15| BW20| BW25| BW40| BW50| BW60| BW100| BW80| BW400| BW200| BW30| BW70| BW90
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:QCKSet:GENeral:CBW?')
		return Conversions.str_to_scalar_enum(response, enums.Nr5Gcbw)

	def set_cbw(self, qck_set_channel_bw: enums.Nr5Gcbw) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:QCKSet:GENeral:CBW \n
		Snippet: driver.source.bb.nr5G.qckset.general.set_cbw(qck_set_channel_bw = enums.Nr5Gcbw.BW10) \n
		Selects the bandwidth of the node carrier. \n
			:param qck_set_channel_bw: BW5| BW10| BW15| BW20| BW25| BW40| BW50| BW60| BW100| BW80| BW400| BW200| BW30| BW70| BW90
		"""
		param = Conversions.enum_scalar_to_str(qck_set_channel_bw, enums.Nr5Gcbw)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:QCKSet:GENeral:CBW {param}')

	def get_cct_model(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:NR5G:QCKSet:GENeral:CCTModel \n
		Snippet: value: bool = driver.source.bb.nr5G.qckset.general.get_cct_model() \n
		Creates a copy of a component carrier based on a test model configuration.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Select a single carrier ([:SOURce<hw>]:BB:NR5G:QCKSet:GENeral:NCARier) .
			- Select a test model ([:SOURce<hw>]:BB:NR5G:SETTing:TMODel:DL / [:SOURce<hw>]:BB:NR5G:SETTing:TMODel:UL) . \n
			:return: qck_set_use_tm: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:QCKSet:GENeral:CCTModel?')
		return Conversions.str_to_bool(response)

	def set_cct_model(self, qck_set_use_tm: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:QCKSet:GENeral:CCTModel \n
		Snippet: driver.source.bb.nr5G.qckset.general.set_cct_model(qck_set_use_tm = False) \n
		Creates a copy of a component carrier based on a test model configuration.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Select a single carrier ([:SOURce<hw>]:BB:NR5G:QCKSet:GENeral:NCARier) .
			- Select a test model ([:SOURce<hw>]:BB:NR5G:SETTing:TMODel:DL / [:SOURce<hw>]:BB:NR5G:SETTing:TMODel:UL) . \n
			:param qck_set_use_tm: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(qck_set_use_tm)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:QCKSet:GENeral:CCTModel {param}')

	# noinspection PyTypeChecker
	def get_ch_raster(self) -> enums.AllChannelRaster:
		"""SCPI: [SOURce<HW>]:BB:NR5G:QCKSet:GENeral:CHRaster \n
		Snippet: value: enums.AllChannelRaster = driver.source.bb.nr5G.qckset.general.get_ch_raster() \n
		Sets the 'Channel Raster' based on the set 'Deployment'. If 'Deployment' is set to 'FR1 ≤ 3GHz' or 'FR1 > 3GHz' the
		'Channel Raster' can be set to 15 kHz or 100 kHz. If 'Deployment' is set to 'FR2' the 'Channel Raster' is set to 60 kHz.
		'Channel Raster' is not displayed when the 'Number of Carriers' is shown inactive. \n
			:return: channel_raster: R15| R60| R100
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:QCKSet:GENeral:CHRaster?')
		return Conversions.str_to_scalar_enum(response, enums.AllChannelRaster)

	def set_ch_raster(self, channel_raster: enums.AllChannelRaster) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:QCKSet:GENeral:CHRaster \n
		Snippet: driver.source.bb.nr5G.qckset.general.set_ch_raster(channel_raster = enums.AllChannelRaster.R100) \n
		Sets the 'Channel Raster' based on the set 'Deployment'. If 'Deployment' is set to 'FR1 ≤ 3GHz' or 'FR1 > 3GHz' the
		'Channel Raster' can be set to 15 kHz or 100 kHz. If 'Deployment' is set to 'FR2' the 'Channel Raster' is set to 60 kHz.
		'Channel Raster' is not displayed when the 'Number of Carriers' is shown inactive. \n
			:param channel_raster: R15| R60| R100
		"""
		param = Conversions.enum_scalar_to_str(channel_raster, enums.AllChannelRaster)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:QCKSet:GENeral:CHRaster {param}')

	def get_ch_spacing(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:NR5G:QCKSet:GENeral:CHSPacing \n
		Snippet: value: int = driver.source.bb.nr5G.qckset.general.get_ch_spacing() \n
		Queries or sets the value for the 'Channel Spacing'. It is by default automatically calculated by the set 'Channel
		Raster' and the set 'Channel Bandwidth'. The value can be manually adjusted, but is recalculated if the 'Channel Raster'
		or the 'Channel Bandwidth' is adjusted. 'Channel Spacing' is not displayed when the 'Number of Carriers' is shown
		inactive. In this case, it is used like 'Carrier Spacing' equals 0. \n
			:return: channel_spacing: integer Range: 0 to 400E6
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:QCKSet:GENeral:CHSPacing?')
		return Conversions.str_to_int(response)

	def set_ch_spacing(self, channel_spacing: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:QCKSet:GENeral:CHSPacing \n
		Snippet: driver.source.bb.nr5G.qckset.general.set_ch_spacing(channel_spacing = 1) \n
		Queries or sets the value for the 'Channel Spacing'. It is by default automatically calculated by the set 'Channel
		Raster' and the set 'Channel Bandwidth'. The value can be manually adjusted, but is recalculated if the 'Channel Raster'
		or the 'Channel Bandwidth' is adjusted. 'Channel Spacing' is not displayed when the 'Number of Carriers' is shown
		inactive. In this case, it is used like 'Carrier Spacing' equals 0. \n
			:param channel_spacing: integer Range: 0 to 400E6
		"""
		param = Conversions.decimal_value_to_str(channel_spacing)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:QCKSet:GENeral:CHSPacing {param}')

	# noinspection PyTypeChecker
	def get_duplexing(self) -> enums.EutraDuplexMode:
		"""SCPI: [SOURce<HW>]:BB:NR5G:QCKSet:GENeral:DUPLexing \n
		Snippet: value: enums.EutraDuplexMode = driver.source.bb.nr5G.qckset.general.get_duplexing() \n
		Selects the duplexing mode. \n
			:return: qck_set_duplexing: TDD| FDD
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:QCKSet:GENeral:DUPLexing?')
		return Conversions.str_to_scalar_enum(response, enums.EutraDuplexMode)

	def set_duplexing(self, qck_set_duplexing: enums.EutraDuplexMode) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:QCKSet:GENeral:DUPLexing \n
		Snippet: driver.source.bb.nr5G.qckset.general.set_duplexing(qck_set_duplexing = enums.EutraDuplexMode.FDD) \n
		Selects the duplexing mode. \n
			:param qck_set_duplexing: TDD| FDD
		"""
		param = Conversions.enum_scalar_to_str(qck_set_duplexing, enums.EutraDuplexMode)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:QCKSet:GENeral:DUPLexing {param}')

	def get_ecp_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:NR5G:QCKSet:GENeral:ECPState \n
		Snippet: value: bool = driver.source.bb.nr5G.qckset.general.get_ecp_state() \n
		Show if the extended cyclic prefix is enabled or disabled. \n
			:return: qss_cs_ecp_state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:QCKSet:GENeral:ECPState?')
		return Conversions.str_to_bool(response)

	def set_ecp_state(self, qss_cs_ecp_state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:QCKSet:GENeral:ECPState \n
		Snippet: driver.source.bb.nr5G.qckset.general.set_ecp_state(qss_cs_ecp_state = False) \n
		Show if the extended cyclic prefix is enabled or disabled. \n
			:param qss_cs_ecp_state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(qss_cs_ecp_state)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:QCKSet:GENeral:ECPState {param}')

	def get_ncarrier(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:NR5G:QCKSet:GENeral:NCARier \n
		Snippet: value: int = driver.source.bb.nr5G.qckset.general.get_ncarrier() \n
		Selects the number of carriers. Needed for carrier aggregation. \n
			:return: qck_set_num_carrier: integer Range: 1 to 16
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:QCKSet:GENeral:NCARier?')
		return Conversions.str_to_int(response)

	def set_ncarrier(self, qck_set_num_carrier: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:QCKSet:GENeral:NCARier \n
		Snippet: driver.source.bb.nr5G.qckset.general.set_ncarrier(qck_set_num_carrier = 1) \n
		Selects the number of carriers. Needed for carrier aggregation. \n
			:param qck_set_num_carrier: integer Range: 1 to 16
		"""
		param = Conversions.decimal_value_to_str(qck_set_num_carrier)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:QCKSet:GENeral:NCARier {param}')

	# noinspection PyTypeChecker
	def get_sc_spacing(self) -> enums.QucjSettingsScsAll:
		"""SCPI: [SOURce<HW>]:BB:NR5G:QCKSet:GENeral:SCSPacing \n
		Snippet: value: enums.QucjSettingsScsAll = driver.source.bb.nr5G.qckset.general.get_sc_spacing() \n
		Sets the subcarrier spacing. \n
			:return: qck_set_scs: SCS15| SCS30| SCS60| SCS120| SCS240
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:QCKSet:GENeral:SCSPacing?')
		return Conversions.str_to_scalar_enum(response, enums.QucjSettingsScsAll)

	def set_sc_spacing(self, qck_set_scs: enums.QucjSettingsScsAll) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:QCKSet:GENeral:SCSPacing \n
		Snippet: driver.source.bb.nr5G.qckset.general.set_sc_spacing(qck_set_scs = enums.QucjSettingsScsAll.N120) \n
		Sets the subcarrier spacing. \n
			:param qck_set_scs: SCS15| SCS30| SCS60| SCS120| SCS240
		"""
		param = Conversions.enum_scalar_to_str(qck_set_scs, enums.QucjSettingsScsAll)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:QCKSet:GENeral:SCSPacing {param}')

	def clone(self) -> 'General':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = General(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Hsch:
	"""Hsch commands group definition. 4 total commands, 4 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("hsch", core, parent)

	@property
	def cvpb(self):
		"""cvpb commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cvpb'):
			from .Cvpb import Cvpb
			self._cvpb = Cvpb(self._core, self._base)
		return self._cvpb

	@property
	def prsr(self):
		"""prsr commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_prsr'):
			from .Prsr import Prsr
			self._prsr = Prsr(self._core, self._base)
		return self._prsr

	@property
	def psbs(self):
		"""psbs commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_psbs'):
			from .Psbs import Psbs
			self._psbs = Psbs(self._core, self._base)
		return self._psbs

	@property
	def rvParameter(self):
		"""rvParameter commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rvParameter'):
			from .RvParameter import RvParameter
			self._rvParameter = RvParameter(self._core, self._base)
		return self._rvParameter

	def clone(self) -> 'Hsch':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Hsch(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Antenna:
	"""Antenna commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("antenna", core, parent)

	def set(self, antenna: enums.AntennaNr, stream=repcap.Stream.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:STReam<ST>:ANTenna \n
		Snippet: driver.source.bb.gnss.stream.antenna.set(antenna = enums.AntennaNr.A1, stream = repcap.Stream.Default) \n
		Selects the signal of which antenna is carried by which stream. \n
			:param antenna: A1| A2| A3| A4
			:param stream: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Stream')"""
		param = Conversions.enum_scalar_to_str(antenna, enums.AntennaNr)
		stream_cmd_val = self._base.get_repcap_cmd_value(stream, repcap.Stream)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:STReam{stream_cmd_val}:ANTenna {param}')

	# noinspection PyTypeChecker
	def get(self, stream=repcap.Stream.Default) -> enums.AntennaNr:
		"""SCPI: [SOURce<HW>]:BB:GNSS:STReam<ST>:ANTenna \n
		Snippet: value: enums.AntennaNr = driver.source.bb.gnss.stream.antenna.get(stream = repcap.Stream.Default) \n
		Selects the signal of which antenna is carried by which stream. \n
			:param stream: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Stream')
			:return: antenna: A1| A2| A3| A4"""
		stream_cmd_val = self._base.get_repcap_cmd_value(stream, repcap.Stream)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:STReam{stream_cmd_val}:ANTenna?')
		return Conversions.str_to_scalar_enum(response, enums.AntennaNr)



"""See the class docstring."""

from enum import Enum

from .Conversions import str_to_bool, str_to_int, str_to_int_or_bool, str_to_float, str_to_float_or_bool, str_to_scalar_enum_helper
from .Conversions import str_to_str_list, str_to_bool_list, str_to_int_list, str_to_int_or_bool_list, str_to_float_list, str_to_float_or_bool_list, str_to_list_enum_helper
from .Types import DataType
from .Utilities import trim_str_response
from .InstrumentErrors import RsInstrException


class ConverterFromScpiString:
	"""Converter from SCPI response string to argument value
	For list argument types, you must use the method get_one_element_value in a loop for each element.
	Provides methods:
	- get_one_element_value(str): returns one scalar value converted from the SCPI string.
	- get_list_value(str): return complete list value converted from the SCPI string.
	- get_value(str): calls either get_one_element_value or get_list_value() depending on the data type. \n
	The reason for the different methods is, that sometimes the list data are interleaved with other arguments.
	In order to parse them properly, the ArgStructStringParser module must be able to set the argument value element-by-element.
	On the other side, the driver methods might want to set the whole argument value, because the result scpi string is a single argument response."""

	def __init__(self, data_type: DataType, enum_type: Enum = None):
		self.enum_type = enum_type
		self.data_type = data_type
		self.element_type = self.data_type.element_type

		if self.element_type == DataType.RawString:
			self.converter = trim_str_response
			self.list_converter = str_to_str_list

		elif self.element_type == DataType.String:
			self.converter = trim_str_response
			self.list_converter = str_to_str_list

		elif self.element_type == DataType.Boolean:
			self.converter = str_to_bool
			self.list_converter = str_to_bool_list

		elif self.element_type == DataType.Integer:
			self.converter = str_to_int
			self.list_converter = str_to_int_list

		elif self.element_type == DataType.IntegerExt:
			self.converter = str_to_int_or_bool
			self.list_converter = str_to_int_or_bool_list

		elif self.element_type == DataType.Float:
			self.converter = str_to_float
			self.list_converter = str_to_float_list

		elif self.element_type == DataType.FloatExt:
			self.converter = str_to_float_or_bool
			self.list_converter = str_to_float_or_bool_list

		elif self.element_type == DataType.Enum:
			assert self.enum_type, f"For data type enum, you have to define the enum_type variable."
			# noinspection PyTypeChecker
			self.enum_members = [x.name for x in self.enum_type]
		else:
			raise RsInstrException(f"Unsupported data type '{data_type}'")

	def get_one_element_value(self, scpi_string: str):
		"""Returns single element !!! of the argument value converted from the SCPI string (single element)"""
		assert isinstance(scpi_string, str), f"Input parameter scpi_string must be string. Actual parameter: {type(scpi_string)}, value: {scpi_string}"
		if self.element_type is DataType.Enum:
			return str_to_scalar_enum_helper(scpi_string, self.enum_type, self.enum_members)
		return self.converter(scpi_string)

	def get_value(self, scpi_string: str):
		"""Returns complete value of the argument converted from the SCPI string (list or scalar)"""
		if not self.data_type.is_list:
			return self.get_one_element_value(scpi_string)

		assert isinstance(scpi_string, str), f"Input parameter scpi_string must be string. Actual parameter: {type(scpi_string)}, value: {scpi_string}"
		if self.element_type is DataType.Enum:
			return str_to_list_enum_helper(scpi_string, self.enum_type, self.enum_members)
		return self.list_converter(scpi_string)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Frequency:
	"""Frequency commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("frequency", core, parent)

	def get_max(self) -> float:
		"""SCPI: [SOURce<HW>]:FREQuency:CONVerter:EXTernal:OVERrange:FREQuency:MAX \n
		Snippet: value: float = driver.source.frequency.converter.external.overrange.frequency.get_max() \n
		Indicates the minimum and maximum frequency range values of the connected R&S SZU. The frequency overrange is based on
		the calibration data of the specific device. \n
			:return: overrang_freq_max: float Range: OverrangeMin to OverrangeMax
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FREQuency:CONVerter:EXTernal:OVERrange:FREQuency:MAX?')
		return Conversions.str_to_float(response)

	def get_min(self) -> float:
		"""SCPI: [SOURce<HW>]:FREQuency:CONVerter:EXTernal:OVERrange:FREQuency:MIN \n
		Snippet: value: float = driver.source.frequency.converter.external.overrange.frequency.get_min() \n
		Indicates the minimum frequency value of the connected R&S SZU. The frequency overrange is based on the calibration data
		of the specific device. \n
			:return: overrang_min_freq: float Range: OverrangeMin to OverrangeMax
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FREQuency:CONVerter:EXTernal:OVERrange:FREQuency:MIN?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NsRatio:
	"""NsRatio commands group definition. 2 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("nsRatio", core, parent)

	@property
	def mtime(self):
		"""mtime commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mtime'):
			from .Mtime import Mtime
			self._mtime = Mtime(self._core, self._base)
		return self._mtime

	def set(self, ns_ratio: float, channel=repcap.Channel.Default) -> None:
		"""SCPI: SENSe<CH>:[POWer]:FILTer:NSRatio \n
		Snippet: driver.sense.power.filterPy.nsRatio.set(ns_ratio = 1.0, channel = repcap.Channel.Default) \n
		Sets an upper limit for the relative noise content in fixed noise filter mode (FILTer:TYPE) . This value determines the
		proportion of intrinsic noise in the measurement results. \n
			:param ns_ratio: float Range: 0.001 to 1
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sense')"""
		param = Conversions.decimal_value_to_str(ns_ratio)
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SENSe{channel_cmd_val}:POWer:FILTer:NSRatio {param}')

	def get(self, channel=repcap.Channel.Default) -> float:
		"""SCPI: SENSe<CH>:[POWer]:FILTer:NSRatio \n
		Snippet: value: float = driver.sense.power.filterPy.nsRatio.get(channel = repcap.Channel.Default) \n
		Sets an upper limit for the relative noise content in fixed noise filter mode (FILTer:TYPE) . This value determines the
		proportion of intrinsic noise in the measurement results. \n
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sense')
			:return: ns_ratio: float Range: 0.001 to 1"""
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'SENSe{channel_cmd_val}:POWer:FILTer:NSRatio?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'NsRatio':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = NsRatio(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Increment:
	"""Increment commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("increment", core, parent)

	def set(self, ipart_increment: float, iqConnector=repcap.IqConnector.Default) -> None:
		"""SCPI: [SOURce]:IQ:OUTPut:DIGital:BBMM<CH>:POWer:STEP:[INCRement] \n
		Snippet: driver.source.iq.output.digital.bbmm.power.step.increment.set(ipart_increment = 1.0, iqConnector = repcap.IqConnector.Default) \n
		Sets the step width. Use this value to vary the digital I/Q output level step-by-step. \n
			:param ipart_increment: float Range: 0 to 100
			:param iqConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bbmm')"""
		param = Conversions.decimal_value_to_str(ipart_increment)
		iqConnector_cmd_val = self._base.get_repcap_cmd_value(iqConnector, repcap.IqConnector)
		self._core.io.write(f'SOURce:IQ:OUTPut:DIGital:BBMM{iqConnector_cmd_val}:POWer:STEP:INCRement {param}')

	def get(self, iqConnector=repcap.IqConnector.Default) -> float:
		"""SCPI: [SOURce]:IQ:OUTPut:DIGital:BBMM<CH>:POWer:STEP:[INCRement] \n
		Snippet: value: float = driver.source.iq.output.digital.bbmm.power.step.increment.get(iqConnector = repcap.IqConnector.Default) \n
		Sets the step width. Use this value to vary the digital I/Q output level step-by-step. \n
			:param iqConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bbmm')
			:return: ipart_increment: No help available"""
		iqConnector_cmd_val = self._base.get_repcap_cmd_value(iqConnector, repcap.IqConnector)
		response = self._core.io.query_str(f'SOURce:IQ:OUTPut:DIGital:BBMM{iqConnector_cmd_val}:POWer:STEP:INCRement?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SlOrder:
	"""SlOrder commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("slOrder", core, parent)

	def set(self, scl_order: int, commandBlock=repcap.CommandBlock.Default, fmBlock=repcap.FmBlock.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NFC:CBLock<CH>:BLOCk<ST>:SLORder \n
		Snippet: driver.source.bb.nfc.cblock.block.slOrder.set(scl_order = 1, commandBlock = repcap.CommandBlock.Default, fmBlock = repcap.FmBlock.Default) \n
		Sets the service code list order. \n
			:param scl_order: integer Range: 0 to dynamic
			:param commandBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cblock')
			:param fmBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Block')"""
		param = Conversions.decimal_value_to_str(scl_order)
		commandBlock_cmd_val = self._base.get_repcap_cmd_value(commandBlock, repcap.CommandBlock)
		fmBlock_cmd_val = self._base.get_repcap_cmd_value(fmBlock, repcap.FmBlock)
		self._core.io.write(f'SOURce<HwInstance>:BB:NFC:CBLock{commandBlock_cmd_val}:BLOCk{fmBlock_cmd_val}:SLORder {param}')

	def get(self, commandBlock=repcap.CommandBlock.Default, fmBlock=repcap.FmBlock.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:NFC:CBLock<CH>:BLOCk<ST>:SLORder \n
		Snippet: value: int = driver.source.bb.nfc.cblock.block.slOrder.get(commandBlock = repcap.CommandBlock.Default, fmBlock = repcap.FmBlock.Default) \n
		Sets the service code list order. \n
			:param commandBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cblock')
			:param fmBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Block')
			:return: scl_order: integer Range: 0 to dynamic"""
		commandBlock_cmd_val = self._base.get_repcap_cmd_value(commandBlock, repcap.CommandBlock)
		fmBlock_cmd_val = self._base.get_repcap_cmd_value(fmBlock, repcap.FmBlock)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NFC:CBLock{commandBlock_cmd_val}:BLOCk{fmBlock_cmd_val}:SLORder?')
		return Conversions.str_to_int(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Additional:
	"""Additional commands group definition. 5 total commands, 3 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("additional", core, parent)

	@property
	def power(self):
		"""power commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_power'):
			from .Power import Power
			self._power = Power(self._core, self._base)
		return self._power

	@property
	def scode(self):
		"""scode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_scode'):
			from .Scode import Scode
			self._scode = Scode(self._core, self._base)
		return self._scode

	@property
	def tdelay(self):
		"""tdelay commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tdelay'):
			from .Tdelay import Tdelay
			self._tdelay = Tdelay(self._core, self._base)
		return self._tdelay

	def get_count(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation:ADDitional:COUNt \n
		Snippet: value: int = driver.source.bb.w3Gpp.mstation.additional.get_count() \n
		The command sets the amount of additional user equipment. Up to 128 additional user equipment can be simulated -
		corresponding to a receive signal for a base station with high capacity utilization. The fourth user equipment (UE4)
		serves as a template for all other stations. The only parameters of the additional user equipment to be modified are the
		scrambling code and the power. \n
			:return: count: integer Range: 1 to 128
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:W3GPp:MSTation:ADDitional:COUNt?')
		return Conversions.str_to_int(response)

	def set_count(self, count: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation:ADDitional:COUNt \n
		Snippet: driver.source.bb.w3Gpp.mstation.additional.set_count(count = 1) \n
		The command sets the amount of additional user equipment. Up to 128 additional user equipment can be simulated -
		corresponding to a receive signal for a base station with high capacity utilization. The fourth user equipment (UE4)
		serves as a template for all other stations. The only parameters of the additional user equipment to be modified are the
		scrambling code and the power. \n
			:param count: integer Range: 1 to 128
		"""
		param = Conversions.decimal_value_to_str(count)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:MSTation:ADDitional:COUNt {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation:ADDitional:STATe \n
		Snippet: value: bool = driver.source.bb.w3Gpp.mstation.additional.get_state() \n
		Activates additional user equipment. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:W3GPp:MSTation:ADDitional:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation:ADDitional:STATe \n
		Snippet: driver.source.bb.w3Gpp.mstation.additional.set_state(state = False) \n
		Activates additional user equipment. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:MSTation:ADDitional:STATe {param}')

	def clone(self) -> 'Additional':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Additional(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Mode:
	"""Mode commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("mode", core, parent)

	def set(self, mode: enums.EutraSlMode, userEquipment=repcap.UserEquipment.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:UE<ST>:SL:MODE \n
		Snippet: driver.source.bb.eutra.uplink.ue.sl.mode.set(mode = enums.EutraSlMode.COMM, userEquipment = repcap.UserEquipment.Default) \n
		Sets the mode of the sidelink communication. \n
			:param mode: COMM| DISC | V2X
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')"""
		param = Conversions.enum_scalar_to_str(mode, enums.EutraSlMode)
		userEquipment_cmd_val = self._base.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{userEquipment_cmd_val}:SL:MODE {param}')

	# noinspection PyTypeChecker
	def get(self, userEquipment=repcap.UserEquipment.Default) -> enums.EutraSlMode:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:UE<ST>:SL:MODE \n
		Snippet: value: enums.EutraSlMode = driver.source.bb.eutra.uplink.ue.sl.mode.get(userEquipment = repcap.UserEquipment.Default) \n
		Sets the mode of the sidelink communication. \n
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
			:return: mode: COMM| DISC | V2X"""
		userEquipment_cmd_val = self._base.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{userEquipment_cmd_val}:SL:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.EutraSlMode)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal.RepeatedCapability import RepeatedCapability
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Sci:
	"""Sci commands group definition. 19 total commands, 19 Sub-groups, 0 group commands
	Repeated Capability: IndexNull, default value after init: IndexNull.Nr0"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("sci", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_indexNull_get', 'repcap_indexNull_set', repcap.IndexNull.Nr0)

	def repcap_indexNull_set(self, enum_value: repcap.IndexNull) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to IndexNull.Default
		Default value after init: IndexNull.Nr0"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_indexNull_get(self) -> repcap.IndexNull:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	@property
	def bitData(self):
		"""bitData commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bitData'):
			from .BitData import BitData
			self._bitData = BitData(self._core, self._base)
		return self._bitData

	@property
	def fhFlag(self):
		"""fhFlag commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fhFlag'):
			from .FhFlag import FhFlag
			self._fhFlag = FhFlag(self._core, self._base)
		return self._fhFlag

	@property
	def formatPy(self):
		"""formatPy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_formatPy'):
			from .FormatPy import FormatPy
			self._formatPy = FormatPy(self._core, self._base)
		return self._formatPy

	@property
	def freqResloc(self):
		"""freqResloc commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_freqResloc'):
			from .FreqResloc import FreqResloc
			self._freqResloc = FreqResloc(self._core, self._base)
		return self._freqResloc

	@property
	def grid(self):
		"""grid commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_grid'):
			from .Grid import Grid
			self._grid = Grid(self._core, self._base)
		return self._grid

	@property
	def mcs(self):
		"""mcs commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mcs'):
			from .Mcs import Mcs
			self._mcs = Mcs(self._core, self._base)
		return self._mcs

	@property
	def npscch(self):
		"""npscch commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_npscch'):
			from .Npscch import Npscch
			self._npscch = Npscch(self._core, self._base)
		return self._npscch

	@property
	def pririty(self):
		"""pririty commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pririty'):
			from .Pririty import Pririty
			self._pririty = Pririty(self._core, self._base)
		return self._pririty

	@property
	def pscPeriod(self):
		"""pscPeriod commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pscPeriod'):
			from .PscPeriod import PscPeriod
			self._pscPeriod = PscPeriod(self._core, self._base)
		return self._pscPeriod

	@property
	def rbahoppAlloc(self):
		"""rbahoppAlloc commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rbahoppAlloc'):
			from .RbahoppAlloc import RbahoppAlloc
			self._rbahoppAlloc = RbahoppAlloc(self._core, self._base)
		return self._rbahoppAlloc

	@property
	def rreservation(self):
		"""rreservation commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rreservation'):
			from .Rreservation import Rreservation
			self._rreservation = Rreservation(self._core, self._base)
		return self._rreservation

	@property
	def sf(self):
		"""sf commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sf'):
			from .Sf import Sf
			self._sf = Sf(self._core, self._base)
		return self._sf

	@property
	def startSf(self):
		"""startSf commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_startSf'):
			from .StartSf import StartSf
			self._startSf = StartSf(self._core, self._base)
		return self._startSf

	@property
	def subChannel(self):
		"""subChannel commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_subChannel'):
			from .SubChannel import SubChannel
			self._subChannel = SubChannel(self._core, self._base)
		return self._subChannel

	@property
	def taInd(self):
		"""taInd commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_taInd'):
			from .TaInd import TaInd
			self._taInd = TaInd(self._core, self._base)
		return self._taInd

	@property
	def timGap(self):
		"""timGap commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_timGap'):
			from .TimGap import TimGap
			self._timGap = TimGap(self._core, self._base)
		return self._timGap

	@property
	def trp(self):
		"""trp commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_trp'):
			from .Trp import Trp
			self._trp = Trp(self._core, self._base)
		return self._trp

	@property
	def txIndex(self):
		"""txIndex commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_txIndex'):
			from .TxIndex import TxIndex
			self._txIndex = TxIndex(self._core, self._base)
		return self._txIndex

	@property
	def txMode(self):
		"""txMode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_txMode'):
			from .TxMode import TxMode
			self._txMode = TxMode(self._core, self._base)
		return self._txMode

	def clone(self) -> 'Sci':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Sci(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Data:
	"""Data commands group definition. 3 total commands, 2 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("data", core, parent)

	@property
	def dselect(self):
		"""dselect commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dselect'):
			from .Dselect import Dselect
			self._dselect = Dselect(self._core, self._base)
		return self._dselect

	@property
	def pattern(self):
		"""pattern commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pattern'):
			from .Pattern import Pattern
			self._pattern = Pattern(self._core, self._base)
		return self._pattern

	def set(self, data: enums.DataSourceA, mobileStation=repcap.MobileStation.Default, channel=repcap.Channel.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation<ST>:CHANnel<CH>:DPDCh:DATA \n
		Snippet: driver.source.bb.w3Gpp.mstation.channel.dpdch.data.set(data = enums.DataSourceA.DLISt, mobileStation = repcap.MobileStation.Default, channel = repcap.Channel.Default) \n
		The command determines the data source for the selected DPDCH. For the enhanced channels of user equipment 1 (UE1) , this
		entry is valid when channel coding is deactivated. When channel coding is active, data sources are selected for the
		transport channels with the commands BB:W3GPp:MST:CHANnel:DPDCh:DCCH:DATA and BB:W3GPp:MST:ENHanced:TCHannel:DATA. \n
			:param data: PN9| PN11| PN15| PN16| PN20| PN21| PN23| DLISt| ZERO | ONE| PATTern PNxx The pseudo-random sequence generator is used as the data source. Different random sequence lengths can be selected. DLISt A data list is used. The data list is selected with the command [:SOURcehw]:BB:W3GPp:MSTationst:CHANnelch:DPDCh:DATA:DSELect. ZERO | ONE Internal 0 and 1 data is used. PATTern Internal data is used. The bit pattern for the data is defined by the command [:SOURcehw]:BB:W3GPp:MSTationst:CHANnelch:DPDCh:DATA:PATTern.
			:param mobileStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mstation')
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Channel')"""
		param = Conversions.enum_scalar_to_str(data, enums.DataSourceA)
		mobileStation_cmd_val = self._base.get_repcap_cmd_value(mobileStation, repcap.MobileStation)
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:MSTation{mobileStation_cmd_val}:CHANnel{channel_cmd_val}:DPDCh:DATA {param}')

	# noinspection PyTypeChecker
	def get(self, mobileStation=repcap.MobileStation.Default, channel=repcap.Channel.Default) -> enums.DataSourceA:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation<ST>:CHANnel<CH>:DPDCh:DATA \n
		Snippet: value: enums.DataSourceA = driver.source.bb.w3Gpp.mstation.channel.dpdch.data.get(mobileStation = repcap.MobileStation.Default, channel = repcap.Channel.Default) \n
		The command determines the data source for the selected DPDCH. For the enhanced channels of user equipment 1 (UE1) , this
		entry is valid when channel coding is deactivated. When channel coding is active, data sources are selected for the
		transport channels with the commands BB:W3GPp:MST:CHANnel:DPDCh:DCCH:DATA and BB:W3GPp:MST:ENHanced:TCHannel:DATA. \n
			:param mobileStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mstation')
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Channel')
			:return: data: PN9| PN11| PN15| PN16| PN20| PN21| PN23| DLISt| ZERO | ONE| PATTern PNxx The pseudo-random sequence generator is used as the data source. Different random sequence lengths can be selected. DLISt A data list is used. The data list is selected with the command [:SOURcehw]:BB:W3GPp:MSTationst:CHANnelch:DPDCh:DATA:DSELect. ZERO | ONE Internal 0 and 1 data is used. PATTern Internal data is used. The bit pattern for the data is defined by the command [:SOURcehw]:BB:W3GPp:MSTationst:CHANnelch:DPDCh:DATA:PATTern."""
		mobileStation_cmd_val = self._base.get_repcap_cmd_value(mobileStation, repcap.MobileStation)
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:W3GPp:MSTation{mobileStation_cmd_val}:CHANnel{channel_cmd_val}:DPDCh:DATA?')
		return Conversions.str_to_scalar_enum(response, enums.DataSourceA)

	def clone(self) -> 'Data':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Data(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Waveform:
	"""Waveform commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("waveform", core, parent)

	def set_create(self, create_wv_file: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:CFR:WAVeform:CREate \n
		Snippet: driver.source.bb.arbitrary.cfr.waveform.set_create(create_wv_file = '1') \n
		With enabled signal generation, triggers the instrument to save the current settings in a waveform file. Waveform files
		can be further processed. The filename and the directory it is saved in are user-definable; the predefined file extension
		for waveform files is *.wv. \n
			:param create_wv_file: string
		"""
		param = Conversions.value_to_quoted_str(create_wv_file)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:CFR:WAVeform:CREate {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Tmod:
	"""Tmod commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("tmod", core, parent)

	def get_downlink(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:SETTing:TMOD:DL \n
		Snippet: value: str = driver.source.bb.oneweb.setting.tmod.get_downlink() \n
		No command help available \n
			:return: filename: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ONEWeb:SETTing:TMOD:DL?')
		return trim_str_response(response)

	def set_downlink(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:SETTing:TMOD:DL \n
		Snippet: driver.source.bb.oneweb.setting.tmod.set_downlink(filename = '1') \n
		No command help available \n
			:param filename: No help available
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:ONEWeb:SETTing:TMOD:DL {param}')

	def get_tdd(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:SETTing:TMOD:TDD \n
		Snippet: value: str = driver.source.bb.oneweb.setting.tmod.get_tdd() \n
		No command help available \n
			:return: tdd: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ONEWeb:SETTing:TMOD:TDD?')
		return trim_str_response(response)

	def set_tdd(self, tdd: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:SETTing:TMOD:TDD \n
		Snippet: driver.source.bb.oneweb.setting.tmod.set_tdd(tdd = '1') \n
		No command help available \n
			:param tdd: No help available
		"""
		param = Conversions.value_to_quoted_str(tdd)
		self._core.io.write(f'SOURce<HwInstance>:BB:ONEWeb:SETTing:TMOD:TDD {param}')



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup
from ...........Internal.RepeatedCapability import RepeatedCapability
from ........... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Alloc:
	"""Alloc commands group definition. 391 total commands, 30 Sub-groups, 0 group commands
	Repeated Capability: AllocationNull, default value after init: AllocationNull.Nr0"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("alloc", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_allocationNull_get', 'repcap_allocationNull_set', repcap.AllocationNull.Nr0)

	def repcap_allocationNull_set(self, enum_value: repcap.AllocationNull) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to AllocationNull.Default
		Default value after init: AllocationNull.Nr0"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_allocationNull_get(self) -> repcap.AllocationNull:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	@property
	def agft(self):
		"""agft commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_agft'):
			from .Agft import Agft
			self._agft = Agft(self._core, self._base)
		return self._agft

	@property
	def agOffset(self):
		"""agOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_agOffset'):
			from .AgOffset import AgOffset
			self._agOffset = AgOffset(self._core, self._base)
		return self._agOffset

	@property
	def apMap(self):
		"""apMap commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_apMap'):
			from .ApMap import ApMap
			self._apMap = ApMap(self._core, self._base)
		return self._apMap

	@property
	def conflict(self):
		"""conflict commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_conflict'):
			from .Conflict import Conflict
			self._conflict = Conflict(self._core, self._base)
		return self._conflict

	@property
	def content(self):
		"""content commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_content'):
			from .Content import Content
			self._content = Content(self._core, self._base)
		return self._content

	@property
	def copyTo(self):
		"""copyTo commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_copyTo'):
			from .CopyTo import CopyTo
			self._copyTo = CopyTo(self._core, self._base)
		return self._copyTo

	@property
	def cpext(self):
		"""cpext commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cpext'):
			from .Cpext import Cpext
			self._cpext = Cpext(self._core, self._base)
		return self._cpext

	@property
	def cs(self):
		"""cs commands group. 11 Sub-classes, 0 commands."""
		if not hasattr(self, '_cs'):
			from .Cs import Cs
			self._cs = Cs(self._core, self._base)
		return self._cs

	@property
	def duration(self):
		"""duration commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_duration'):
			from .Duration import Duration
			self._duration = Duration(self._core, self._base)
		return self._duration

	@property
	def fmt(self):
		"""fmt commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fmt'):
			from .Fmt import Fmt
			self._fmt = Fmt(self._core, self._base)
		return self._fmt

	@property
	def info(self):
		"""info commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_info'):
			from .Info import Info
			self._info = Info(self._core, self._base)
		return self._info

	@property
	def mapType(self):
		"""mapType commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mapType'):
			from .MapType import MapType
			self._mapType = MapType(self._core, self._base)
		return self._mapType

	@property
	def nap(self):
		"""nap commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nap'):
			from .Nap import Nap
			self._nap = Nap(self._core, self._base)
		return self._nap

	@property
	def pdsch(self):
		"""pdsch commands group. 11 Sub-classes, 0 commands."""
		if not hasattr(self, '_pdsch'):
			from .Pdsch import Pdsch
			self._pdsch = Pdsch(self._core, self._base)
		return self._pdsch

	@property
	def period(self):
		"""period commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_period'):
			from .Period import Period
			self._period = Period(self._core, self._base)
		return self._period

	@property
	def power(self):
		"""power commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_power'):
			from .Power import Power
			self._power = Power(self._core, self._base)
		return self._power

	@property
	def prach(self):
		"""prach commands group. 8 Sub-classes, 0 commands."""
		if not hasattr(self, '_prach'):
			from .Prach import Prach
			self._prach = Prach(self._core, self._base)
		return self._prach

	@property
	def pucch(self):
		"""pucch commands group. 8 Sub-classes, 0 commands."""
		if not hasattr(self, '_pucch'):
			from .Pucch import Pucch
			self._pucch = Pucch(self._core, self._base)
		return self._pucch

	@property
	def pusch(self):
		"""pusch commands group. 14 Sub-classes, 0 commands."""
		if not hasattr(self, '_pusch'):
			from .Pusch import Pusch
			self._pusch = Pusch(self._core, self._base)
		return self._pusch

	@property
	def rbNumber(self):
		"""rbNumber commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rbNumber'):
			from .RbNumber import RbNumber
			self._rbNumber = RbNumber(self._core, self._base)
		return self._rbNumber

	@property
	def rbOffset(self):
		"""rbOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rbOffset'):
			from .RbOffset import RbOffset
			self._rbOffset = RbOffset(self._core, self._base)
		return self._rbOffset

	@property
	def repetitions(self):
		"""repetitions commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_repetitions'):
			from .Repetitions import Repetitions
			self._repetitions = Repetitions(self._core, self._base)
		return self._repetitions

	@property
	def seqLength(self):
		"""seqLength commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_seqLength'):
			from .SeqLength import SeqLength
			self._seqLength = SeqLength(self._core, self._base)
		return self._seqLength

	@property
	def slot(self):
		"""slot commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_slot'):
			from .Slot import Slot
			self._slot = Slot(self._core, self._base)
		return self._slot

	@property
	def sltFmt(self):
		"""sltFmt commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sltFmt'):
			from .SltFmt import SltFmt
			self._sltFmt = SltFmt(self._core, self._base)
		return self._sltFmt

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import State
			self._state = State(self._core, self._base)
		return self._state

	@property
	def symNumber(self):
		"""symNumber commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_symNumber'):
			from .SymNumber import SymNumber
			self._symNumber = SymNumber(self._core, self._base)
		return self._symNumber

	@property
	def symOffset(self):
		"""symOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_symOffset'):
			from .SymOffset import SymOffset
			self._symOffset = SymOffset(self._core, self._base)
		return self._symOffset

	@property
	def toffset(self):
		"""toffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_toffset'):
			from .Toffset import Toffset
			self._toffset = Toffset(self._core, self._base)
		return self._toffset

	@property
	def cw(self):
		"""cw commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_cw'):
			from .Cw import Cw
			self._cw = Cw(self._core, self._base)
		return self._cw

	def clone(self) -> 'Alloc':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Alloc(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from typing import List

from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Mac:
	"""Mac commands group definition. 25 total commands, 5 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("mac", core, parent)

	@property
	def address(self):
		"""address commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_address'):
			from .Address import Address
			self._address = Address(self._core, self._base)
		return self._address

	@property
	def fcontrol(self):
		"""fcontrol commands group. 0 Sub-classes, 13 commands."""
		if not hasattr(self, '_fcontrol'):
			from .Fcontrol import Fcontrol
			self._fcontrol = Fcontrol(self._core, self._base)
		return self._fcontrol

	@property
	def fcs(self):
		"""fcs commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fcs'):
			from .Fcs import Fcs
			self._fcs = Fcs(self._core, self._base)
		return self._fcs

	@property
	def qsControl(self):
		"""qsControl commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_qsControl'):
			from .QsControl import QsControl
			self._qsControl = QsControl(self._core, self._base)
		return self._qsControl

	@property
	def scontrol(self):
		"""scontrol commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_scontrol'):
			from .Scontrol import Scontrol
			self._scontrol = Scontrol(self._core, self._base)
		return self._scontrol

	def get_did(self) -> List[str]:
		"""SCPI: [SOURce<HW>]:BB:WLAD:PCONfig:MAC:DID \n
		Snippet: value: List[str] = driver.source.bb.wlad.pconfig.mac.get_did() \n
		Sets the value of the duration ID field. Depending on the frame type, the 2-byte field Duration/ID is used to transmit
		the association identity of the station transmitting the frame or it indicates the duration assigned to the frame type.
		Exactly 16 bit must be entered. \n
			:return: did: 16 bits
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:WLAD:PCONfig:MAC:DID?')
		return Conversions.str_to_str_list(response)

	def set_did(self, did: List[str]) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLAD:PCONfig:MAC:DID \n
		Snippet: driver.source.bb.wlad.pconfig.mac.set_did(did = ['raw1', 'raw2', 'raw3']) \n
		Sets the value of the duration ID field. Depending on the frame type, the 2-byte field Duration/ID is used to transmit
		the association identity of the station transmitting the frame or it indicates the duration assigned to the frame type.
		Exactly 16 bit must be entered. \n
			:param did: 16 bits
		"""
		param = Conversions.list_to_csv_str(did)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLAD:PCONfig:MAC:DID {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:WLAD:PCONfig:MAC:STATe \n
		Snippet: value: bool = driver.source.bb.wlad.pconfig.mac.get_state() \n
		Activates/deactivates the generation of the MAC Header. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:WLAD:PCONfig:MAC:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLAD:PCONfig:MAC:STATe \n
		Snippet: driver.source.bb.wlad.pconfig.mac.set_state(state = False) \n
		Activates/deactivates the generation of the MAC Header. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLAD:PCONfig:MAC:STATe {param}')

	def clone(self) -> 'Mac':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Mac(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Release:
	"""Release commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("release", core, parent)

	def set(self, release: enums.UeRelease, userEquipment=repcap.UserEquipment.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:UE<ST>:RELease \n
		Snippet: driver.source.bb.eutra.uplink.ue.release.set(release = enums.UeRelease.EMTC, userEquipment = repcap.UserEquipment.Default) \n
		Sets which LTE release version the UE supports. \n
			:param release: R89| LADV | EMTC| NIOT
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')"""
		param = Conversions.enum_scalar_to_str(release, enums.UeRelease)
		userEquipment_cmd_val = self._base.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{userEquipment_cmd_val}:RELease {param}')

	# noinspection PyTypeChecker
	def get(self, userEquipment=repcap.UserEquipment.Default) -> enums.UeRelease:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:UE<ST>:RELease \n
		Snippet: value: enums.UeRelease = driver.source.bb.eutra.uplink.ue.release.get(userEquipment = repcap.UserEquipment.Default) \n
		Sets which LTE release version the UE supports. \n
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
			:return: release: R89| LADV | EMTC| NIOT"""
		userEquipment_cmd_val = self._base.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{userEquipment_cmd_val}:RELease?')
		return Conversions.str_to_scalar_enum(response, enums.UeRelease)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Sample:
	"""Sample commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("sample", core, parent)

	def get_length(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBH:SAMPle:LENGth \n
		Snippet: value: int = driver.source.bb.dvb.dvbh.sample.get_length() \n
		Queries the number of the transmitted samples. \n
			:return: length: integer
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DVB:DVBH:SAMPle:LENGth?')
		return Conversions.str_to_int(response)

	def get_rate(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBH:SAMPle:RATE \n
		Snippet: value: float = driver.source.bb.dvb.dvbh.sample.get_rate() \n
		Queries the sample rate. \n
			:return: rate: float
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DVB:DVBH:SAMPle:RATE?')
		return Conversions.str_to_float(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Emtc:
	"""Emtc commands group definition. 2 total commands, 2 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("emtc", core, parent)

	@property
	def arb(self):
		"""arb commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_arb'):
			from .Arb import Arb
			self._arb = Arb(self._core, self._base)
		return self._arb

	@property
	def prAttempts(self):
		"""prAttempts commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_prAttempts'):
			from .PrAttempts import PrAttempts
			self._prAttempts = PrAttempts(self._core, self._base)
		return self._prAttempts

	def clone(self) -> 'Emtc':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Emtc(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Scode:
	"""Scode commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("scode", core, parent)

	def set(self, scode: int, cell=repcap.Cell.Default, slotNull=repcap.SlotNull.Default, channelNull=repcap.ChannelNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:DOWN:CELL<ST>:SLOT<CH0>:CHANnel<US0>:SCODe \n
		Snippet: driver.source.bb.tdscdma.down.cell.slot.channel.scode.set(scode = 1, cell = repcap.Cell.Default, slotNull = repcap.SlotNull.Default, channelNull = repcap.ChannelNull.Default) \n
		Sets the spreading code for the selected channel. The code channel is spread with the set spreading code. The range of
		values of the spreading code depends on the channel type and the spreading factor. Depending on the channel type, the
		range of values can be limited. \n
			:param scode: integer Range: 1 to 16
			:param cell: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cell')
			:param slotNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Slot')
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')"""
		param = Conversions.decimal_value_to_str(scode)
		cell_cmd_val = self._base.get_repcap_cmd_value(cell, repcap.Cell)
		slotNull_cmd_val = self._base.get_repcap_cmd_value(slotNull, repcap.SlotNull)
		channelNull_cmd_val = self._base.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:TDSCdma:DOWN:CELL{cell_cmd_val}:SLOT{slotNull_cmd_val}:CHANnel{channelNull_cmd_val}:SCODe {param}')

	def get(self, cell=repcap.Cell.Default, slotNull=repcap.SlotNull.Default, channelNull=repcap.ChannelNull.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:DOWN:CELL<ST>:SLOT<CH0>:CHANnel<US0>:SCODe \n
		Snippet: value: int = driver.source.bb.tdscdma.down.cell.slot.channel.scode.get(cell = repcap.Cell.Default, slotNull = repcap.SlotNull.Default, channelNull = repcap.ChannelNull.Default) \n
		Sets the spreading code for the selected channel. The code channel is spread with the set spreading code. The range of
		values of the spreading code depends on the channel type and the spreading factor. Depending on the channel type, the
		range of values can be limited. \n
			:param cell: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cell')
			:param slotNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Slot')
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')
			:return: scode: integer Range: 1 to 16"""
		cell_cmd_val = self._base.get_repcap_cmd_value(cell, repcap.Cell)
		slotNull_cmd_val = self._base.get_repcap_cmd_value(slotNull, repcap.SlotNull)
		channelNull_cmd_val = self._base.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:TDSCdma:DOWN:CELL{cell_cmd_val}:SLOT{slotNull_cmd_val}:CHANnel{channelNull_cmd_val}:SCODe?')
		return Conversions.str_to_int(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Bmp:
	"""Bmp commands group definition. 2 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("bmp", core, parent)

	@property
	def valSubFrames(self):
		"""valSubFrames commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_valSubFrames'):
			from .ValSubFrames import ValSubFrames
			self._valSubFrames = ValSubFrames(self._core, self._base)
		return self._valSubFrames

	# noinspection PyTypeChecker
	def get_conf(self) -> enums.EutraBitmap:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:NPRS:BMP:CONF \n
		Snippet: value: enums.EutraBitmap = driver.source.bb.eutra.downlink.niot.nprs.bmp.get_conf() \n
		Sets if the NPRS subframe Part A configuration lasts 10 ms or 40 ms. \n
			:return: nprs_bmp: 10| 40
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:NIOT:NPRS:BMP:CONF?')
		return Conversions.str_to_scalar_enum(response, enums.EutraBitmap)

	def set_conf(self, nprs_bmp: enums.EutraBitmap) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:NPRS:BMP:CONF \n
		Snippet: driver.source.bb.eutra.downlink.niot.nprs.bmp.set_conf(nprs_bmp = enums.EutraBitmap._10) \n
		Sets if the NPRS subframe Part A configuration lasts 10 ms or 40 ms. \n
			:param nprs_bmp: 10| 40
		"""
		param = Conversions.enum_scalar_to_str(nprs_bmp, enums.EutraBitmap)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:NIOT:NPRS:BMP:CONF {param}')

	def clone(self) -> 'Bmp':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Bmp(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Niot:
	"""Niot commands group definition. 2 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("niot", core, parent)

	@property
	def valid(self):
		"""valid commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_valid'):
			from .Valid import Valid
			self._valid = Valid(self._core, self._base)
		return self._valid

	# noinspection PyTypeChecker
	def get_sub_config(self) -> enums.EutraNbiotInbandBitmapSfAll:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:NIOT:SUBConfig \n
		Snippet: value: enums.EutraNbiotInbandBitmapSfAll = driver.source.bb.eutra.uplink.niot.get_sub_config() \n
		Sets the number of subframes in the bitmap. \n
			:return: sf_config: N10| N40
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:UL:NIOT:SUBConfig?')
		return Conversions.str_to_scalar_enum(response, enums.EutraNbiotInbandBitmapSfAll)

	def set_sub_config(self, sf_config: enums.EutraNbiotInbandBitmapSfAll) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:NIOT:SUBConfig \n
		Snippet: driver.source.bb.eutra.uplink.niot.set_sub_config(sf_config = enums.EutraNbiotInbandBitmapSfAll.N10) \n
		Sets the number of subframes in the bitmap. \n
			:param sf_config: N10| N40
		"""
		param = Conversions.enum_scalar_to_str(sf_config, enums.EutraNbiotInbandBitmapSfAll)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:UL:NIOT:SUBConfig {param}')

	def clone(self) -> 'Niot':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Niot(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Phase:
	"""Phase commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("phase", core, parent)

	def set(self, gain: float, mimoTap=repcap.MimoTap.Default) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:MIMO:TAP<CH>:GVECtor:FC:PHASe \n
		Snippet: driver.source.fsimulator.mimo.tap.gvector.fc.phase.set(gain = 1.0, mimoTap = repcap.MimoTap.Default) \n
		No command help available \n
			:param gain: No help available
			:param mimoTap: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Tap')"""
		param = Conversions.decimal_value_to_str(gain)
		mimoTap_cmd_val = self._base.get_repcap_cmd_value(mimoTap, repcap.MimoTap)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:MIMO:TAP{mimoTap_cmd_val}:GVECtor:FC:PHASe {param}')

	def get(self, mimoTap=repcap.MimoTap.Default) -> float:
		"""SCPI: [SOURce<HW>]:FSIMulator:MIMO:TAP<CH>:GVECtor:FC:PHASe \n
		Snippet: value: float = driver.source.fsimulator.mimo.tap.gvector.fc.phase.get(mimoTap = repcap.MimoTap.Default) \n
		No command help available \n
			:param mimoTap: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Tap')
			:return: gain: No help available"""
		mimoTap_cmd_val = self._base.get_repcap_cmd_value(mimoTap, repcap.MimoTap)
		response = self._core.io.query_str(f'SOURce<HwInstance>:FSIMulator:MIMO:TAP{mimoTap_cmd_val}:GVECtor:FC:PHASe?')
		return Conversions.str_to_float(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PointA:
	"""PointA commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("pointA", core, parent)

	def set(self, lte_offs_to_point_a: int, cellNull=repcap.CellNull.Nr0, patternNull=repcap.PatternNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:NODE:CELL<CH0>:LTE:PATT<ST0>:POINta \n
		Snippet: driver.source.bb.nr5G.node.cell.lte.patt.pointA.set(lte_offs_to_point_a = 1, cellNull = repcap.CellNull.Nr0, patternNull = repcap.PatternNull.Default) \n
		Defines an LTE carrier offset relative to reference point A (in terms of resource blocks) .
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Turn on LTE-CRS coexistence ([:SOURce<hw>]:BB:NR5G:NODE:CELL<ch0>:LTE:STATe) . \n
			:param lte_offs_to_point_a: integer Range: 0 to 30300
			:param cellNull: optional repeated capability selector. Default value: Nr0
			:param patternNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Patt')"""
		param = Conversions.decimal_value_to_str(lte_offs_to_point_a)
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		patternNull_cmd_val = self._base.get_repcap_cmd_value(patternNull, repcap.PatternNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:NODE:CELL{cellNull_cmd_val}:LTE:PATT{patternNull_cmd_val}:POINta {param}')

	def get(self, cellNull=repcap.CellNull.Nr0, patternNull=repcap.PatternNull.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:NR5G:NODE:CELL<CH0>:LTE:PATT<ST0>:POINta \n
		Snippet: value: int = driver.source.bb.nr5G.node.cell.lte.patt.pointA.get(cellNull = repcap.CellNull.Nr0, patternNull = repcap.PatternNull.Default) \n
		Defines an LTE carrier offset relative to reference point A (in terms of resource blocks) .
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Turn on LTE-CRS coexistence ([:SOURce<hw>]:BB:NR5G:NODE:CELL<ch0>:LTE:STATe) . \n
			:param cellNull: optional repeated capability selector. Default value: Nr0
			:param patternNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Patt')
			:return: lte_offs_to_point_a: No help available"""
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		patternNull_cmd_val = self._base.get_repcap_cmd_value(patternNull, repcap.PatternNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:NODE:CELL{cellNull_cmd_val}:LTE:PATT{patternNull_cmd_val}:POINta?')
		return Conversions.str_to_int(response)



from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class File:
	"""File commands group definition. 4 total commands, 1 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("file", core, parent)

	@property
	def frequency(self):
		"""frequency commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_frequency'):
			from .Frequency import Frequency
			self._frequency = Frequency(self._core, self._base)
		return self._frequency

	def get_catalog(self) -> List[str]:
		"""SCPI: [SOURce<HW>]:EFRontend:ALIGnment:FILE:CATalog \n
		Snippet: value: List[str] = driver.source.efrontend.alignment.file.get_catalog() \n
		No command help available \n
			:return: freq_conv_fe_cable_corr_cat: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:EFRontend:ALIGnment:FILE:CATalog?')
		return Conversions.str_to_str_list(response)

	def get_select(self) -> str:
		"""SCPI: [SOURce<HW>]:EFRontend:ALIGnment:FILE:[SELect] \n
		Snippet: value: str = driver.source.efrontend.alignment.file.get_select() \n
		Selects an existing correction file to compensate for cable losses. Selectable file have file extension *.s2p. \n
			:return: cable_corr_file_na: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:EFRontend:ALIGnment:FILE:SELect?')
		return trim_str_response(response)

	def set_select(self, cable_corr_file_na: str) -> None:
		"""SCPI: [SOURce<HW>]:EFRontend:ALIGnment:FILE:[SELect] \n
		Snippet: driver.source.efrontend.alignment.file.set_select(cable_corr_file_na = '1') \n
		Selects an existing correction file to compensate for cable losses. Selectable file have file extension *.s2p. \n
			:param cable_corr_file_na: string
		"""
		param = Conversions.value_to_quoted_str(cable_corr_file_na)
		self._core.io.write(f'SOURce<HwInstance>:EFRontend:ALIGnment:FILE:SELect {param}')

	def clone(self) -> 'File':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = File(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from typing import List

from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HeControl:
	"""HeControl commands group definition. 3 total commands, 2 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("heControl", core, parent)

	@property
	def acontrol(self):
		"""acontrol commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_acontrol'):
			from .Acontrol import Acontrol
			self._acontrol = Acontrol(self._core, self._base)
		return self._acontrol

	@property
	def heIndicator(self):
		"""heIndicator commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_heIndicator'):
			from .HeIndicator import HeIndicator
			self._heIndicator = HeIndicator(self._core, self._base)
		return self._heIndicator

	def set(self, he_control: List[str], frameBlock=repcap.FrameBlock.Default, userIx=repcap.UserIx.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:[USER<DI>]:MAC:HEControl \n
		Snippet: driver.source.bb.wlnn.fblock.user.mac.heControl.set(he_control = ['raw1', 'raw2', 'raw3'], frameBlock = repcap.FrameBlock.Default, userIx = repcap.UserIx.Default) \n
		Sets the value with the length of 4 bytes of the HE control field. \n
			:param he_control: integer
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')"""
		param = Conversions.list_to_csv_str(he_control)
		frameBlock_cmd_val = self._base.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		userIx_cmd_val = self._base.get_repcap_cmd_value(userIx, repcap.UserIx)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:USER{userIx_cmd_val}:MAC:HEControl {param}')

	def get(self, frameBlock=repcap.FrameBlock.Default, userIx=repcap.UserIx.Default) -> List[str]:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:[USER<DI>]:MAC:HEControl \n
		Snippet: value: List[str] = driver.source.bb.wlnn.fblock.user.mac.heControl.get(frameBlock = repcap.FrameBlock.Default, userIx = repcap.UserIx.Default) \n
		Sets the value with the length of 4 bytes of the HE control field. \n
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:return: he_control: integer"""
		frameBlock_cmd_val = self._base.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		userIx_cmd_val = self._base.get_repcap_cmd_value(userIx, repcap.UserIx)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:USER{userIx_cmd_val}:MAC:HEControl?')
		return Conversions.str_to_str_list(response)

	def clone(self) -> 'HeControl':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = HeControl(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TypePy:
	"""TypePy commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("typePy", core, parent)

	def set(self, type_py: enums.ChanCodTypeEnhPrac, mobileStation=repcap.MobileStation.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation<ST>:ENHanced:PRACh:CCODing:TYPE \n
		Snippet: driver.source.bb.w3Gpp.mstation.enhanced.prach.ccoding.typePy.set(type_py = enums.ChanCodTypeEnhPrac.TB168, mobileStation = repcap.MobileStation.Default) \n
		The command selects the channel coding scheme in accordance with the 3GPP specification. \n
			:param type_py: TB168| TB360| TU168| TU360 TB168 RACH RMC (TB size 168 bits) TB360 RACH RMC (TB size 360 bits)
			:param mobileStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mstation')"""
		param = Conversions.enum_scalar_to_str(type_py, enums.ChanCodTypeEnhPrac)
		mobileStation_cmd_val = self._base.get_repcap_cmd_value(mobileStation, repcap.MobileStation)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:MSTation{mobileStation_cmd_val}:ENHanced:PRACh:CCODing:TYPE {param}')

	# noinspection PyTypeChecker
	def get(self, mobileStation=repcap.MobileStation.Default) -> enums.ChanCodTypeEnhPrac:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation<ST>:ENHanced:PRACh:CCODing:TYPE \n
		Snippet: value: enums.ChanCodTypeEnhPrac = driver.source.bb.w3Gpp.mstation.enhanced.prach.ccoding.typePy.get(mobileStation = repcap.MobileStation.Default) \n
		The command selects the channel coding scheme in accordance with the 3GPP specification. \n
			:param mobileStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mstation')
			:return: type_py: TB168| TB360| TU168| TU360 TB168 RACH RMC (TB size 168 bits) TB360 RACH RMC (TB size 360 bits)"""
		mobileStation_cmd_val = self._base.get_repcap_cmd_value(mobileStation, repcap.MobileStation)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:W3GPp:MSTation{mobileStation_cmd_val}:ENHanced:PRACh:CCODing:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.ChanCodTypeEnhPrac)



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal.RepeatedCapability import RepeatedCapability
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Bwp:
	"""Bwp commands group definition. 153 total commands, 19 Sub-groups, 0 group commands
	Repeated Capability: BwPartNull, default value after init: BwPartNull.Nr0"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("bwp", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_bwPartNull_get', 'repcap_bwPartNull_set', repcap.BwPartNull.Nr0)

	def repcap_bwPartNull_set(self, enum_value: repcap.BwPartNull) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to BwPartNull.Default
		Default value after init: BwPartNull.Nr0"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_bwPartNull_get(self) -> repcap.BwPartNull:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	@property
	def ciLength(self):
		"""ciLength commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ciLength'):
			from .CiLength import CiLength
			self._ciLength = CiLength(self._core, self._base)
		return self._ciLength

	@property
	def csi(self):
		"""csi commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_csi'):
			from .Csi import Csi
			self._csi = Csi(self._core, self._base)
		return self._csi

	@property
	def csirs(self):
		"""csirs commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_csirs'):
			from .Csirs import Csirs
			self._csirs = Csirs(self._core, self._base)
		return self._csirs

	@property
	def dfreq(self):
		"""dfreq commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dfreq'):
			from .Dfreq import Dfreq
			self._dfreq = Dfreq(self._core, self._base)
		return self._dfreq

	@property
	def indicator(self):
		"""indicator commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_indicator'):
			from .Indicator import Indicator
			self._indicator = Indicator(self._core, self._base)
		return self._indicator

	@property
	def naInd(self):
		"""naInd commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_naInd'):
			from .NaInd import NaInd
			self._naInd = NaInd(self._core, self._base)
		return self._naInd

	@property
	def ncind(self):
		"""ncind commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ncind'):
			from .Ncind import Ncind
			self._ncind = Ncind(self._core, self._base)
		return self._ncind

	@property
	def pdcch(self):
		"""pdcch commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_pdcch'):
			from .Pdcch import Pdcch
			self._pdcch = Pdcch(self._core, self._base)
		return self._pdcch

	@property
	def pdsch(self):
		"""pdsch commands group. 24 Sub-classes, 0 commands."""
		if not hasattr(self, '_pdsch'):
			from .Pdsch import Pdsch
			self._pdsch = Pdsch(self._core, self._base)
		return self._pdsch

	@property
	def prbOffset(self):
		"""prbOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_prbOffset'):
			from .PrbOffset import PrbOffset
			self._prbOffset = PrbOffset(self._core, self._base)
		return self._prbOffset

	@property
	def pucch(self):
		"""pucch commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_pucch'):
			from .Pucch import Pucch
			self._pucch = Pucch(self._core, self._base)
		return self._pucch

	@property
	def pusch(self):
		"""pusch commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_pusch'):
			from .Pusch import Pusch
			self._pusch = Pusch(self._core, self._base)
		return self._pusch

	@property
	def ratm(self):
		"""ratm commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_ratm'):
			from .Ratm import Ratm
			self._ratm = Ratm(self._core, self._base)
		return self._ratm

	@property
	def rbNumber(self):
		"""rbNumber commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rbNumber'):
			from .RbNumber import RbNumber
			self._rbNumber = RbNumber(self._core, self._base)
		return self._rbNumber

	@property
	def rbOffset(self):
		"""rbOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rbOffset'):
			from .RbOffset import RbOffset
			self._rbOffset = RbOffset(self._core, self._base)
		return self._rbOffset

	@property
	def rmc(self):
		"""rmc commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_rmc'):
			from .Rmc import Rmc
			self._rmc = Rmc(self._core, self._base)
		return self._rmc

	@property
	def rnti(self):
		"""rnti commands group. 7 Sub-classes, 0 commands."""
		if not hasattr(self, '_rnti'):
			from .Rnti import Rnti
			self._rnti = Rnti(self._core, self._base)
		return self._rnti

	@property
	def scSpacing(self):
		"""scSpacing commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_scSpacing'):
			from .ScSpacing import ScSpacing
			self._scSpacing = ScSpacing(self._core, self._base)
		return self._scSpacing

	@property
	def srs(self):
		"""srs commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_srs'):
			from .Srs import Srs
			self._srs = Srs(self._core, self._base)
		return self._srs

	def clone(self) -> 'Bwp':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Bwp(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Socket:
	"""Socket commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("socket", core, parent)

	def get_resource(self) -> str:
		"""SCPI: SYSTem:COMMunicate:SOCKet:RESource \n
		Snippet: value: str = driver.system.communicate.socket.get_resource() \n
		Queries the visa resource string for remote control via LAN interface, using TCP/IP socket protocol. \n
			:return: resource: string
		"""
		response = self._core.io.query_str('SYSTem:COMMunicate:SOCKet:RESource?')
		return trim_str_response(response)



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Pts:
	"""Pts commands group definition. 6 total commands, 6 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("pts", core, parent)

	@property
	def distance(self):
		"""distance commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_distance'):
			from .Distance import Distance
			self._distance = Distance(self._core, self._base)
		return self._distance

	@property
	def pcorrection(self):
		"""pcorrection commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pcorrection'):
			from .Pcorrection import Pcorrection
			self._pcorrection = Pcorrection(self._core, self._base)
		return self._pcorrection

	@property
	def power(self):
		"""power commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_power'):
			from .Power import Power
			self._power = Power(self._core, self._base)
		return self._power

	@property
	def pstep(self):
		"""pstep commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pstep'):
			from .Pstep import Pstep
			self._pstep = Pstep(self._core, self._base)
		return self._pstep

	@property
	def repetition(self):
		"""repetition commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_repetition'):
			from .Repetition import Repetition
			self._repetition = Repetition(self._core, self._base)
		return self._repetition

	@property
	def start(self):
		"""start commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_start'):
			from .Start import Start
			self._start = Start(self._core, self._base)
		return self._start

	def clone(self) -> 'Pts':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Pts(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup
from ...........Internal import Conversions
from ........... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class External:
	"""External commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("external", core, parent)

	def set(self, external: float, channelNull=repcap.ChannelNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation:ENHanced:CHANnel<CH0>:DPCH:DPControl:STEP:[EXTernal] \n
		Snippet: driver.source.bb.w3Gpp.bstation.enhanced.channel.dpch.dpControl.step.external.set(external = 1.0, channelNull = repcap.ChannelNull.Default) \n
		This command sets step width by which – with Dynamic Power Control being switched on - the channel power of the selected
		enhanced channel is increased or decreased. \n
			:param external: float Range: 0.5 to 6, Unit: dB
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')"""
		param = Conversions.decimal_value_to_str(external)
		channelNull_cmd_val = self._base.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:BSTation:ENHanced:CHANnel{channelNull_cmd_val}:DPCH:DPControl:STEP:EXTernal {param}')

	def get(self, channelNull=repcap.ChannelNull.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation:ENHanced:CHANnel<CH0>:DPCH:DPControl:STEP:[EXTernal] \n
		Snippet: value: float = driver.source.bb.w3Gpp.bstation.enhanced.channel.dpch.dpControl.step.external.get(channelNull = repcap.ChannelNull.Default) \n
		This command sets step width by which – with Dynamic Power Control being switched on - the channel power of the selected
		enhanced channel is increased or decreased. \n
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')
			:return: external: float Range: 0.5 to 6, Unit: dB"""
		channelNull_cmd_val = self._base.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:W3GPp:BSTation:ENHanced:CHANnel{channelNull_cmd_val}:DPCH:DPControl:STEP:EXTernal?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Offset:
	"""Offset commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("offset", core, parent)

	def set(self, offset_relative_t: enums.OffsetRelativeAll, cellNull=repcap.CellNull.Nr0) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:NODE:CELL<CH0>:OFFSet \n
		Snippet: driver.source.bb.nr5G.node.cell.offset.set(offset_relative_t = enums.OffsetRelativeAll.POINta, cellNull = repcap.CellNull.Nr0) \n
		Defines the reference point, relative to which the SS/PBCH is allocated in frequency domain. \n
			:param offset_relative_t: TXBW| POINta TXBW The frequency position of the SS/PBCH is set relative to the usable RBs that apply for the current numerology, i.e. to the start of the TxBWs. POINta The frequency position of the SS/PBCH is set relative to the position of point A.
			:param cellNull: optional repeated capability selector. Default value: Nr0"""
		param = Conversions.enum_scalar_to_str(offset_relative_t, enums.OffsetRelativeAll)
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:NODE:CELL{cellNull_cmd_val}:OFFSet {param}')

	# noinspection PyTypeChecker
	def get(self, cellNull=repcap.CellNull.Nr0) -> enums.OffsetRelativeAll:
		"""SCPI: [SOURce<HW>]:BB:NR5G:NODE:CELL<CH0>:OFFSet \n
		Snippet: value: enums.OffsetRelativeAll = driver.source.bb.nr5G.node.cell.offset.get(cellNull = repcap.CellNull.Nr0) \n
		Defines the reference point, relative to which the SS/PBCH is allocated in frequency domain. \n
			:param cellNull: optional repeated capability selector. Default value: Nr0
			:return: offset_relative_t: TXBW| POINta TXBW The frequency position of the SS/PBCH is set relative to the usable RBs that apply for the current numerology, i.e. to the start of the TxBWs. POINta The frequency position of the SS/PBCH is set relative to the position of point A."""
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:NODE:CELL{cellNull_cmd_val}:OFFSet?')
		return Conversions.str_to_scalar_enum(response, enums.OffsetRelativeAll)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AtcHeight:
	"""AtcHeight commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("atcHeight", core, parent)

	def set(self, tch: float, vdbTransmitter=repcap.VdbTransmitter.Default, fdbTransmitter=repcap.FdbTransmitter.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GBAS:VDB<CH>:MCONfig:FDB<ST>:ATCHeight \n
		Snippet: driver.source.bb.gbas.vdb.mconfig.fdb.atcHeight.set(tch = 1.0, vdbTransmitter = repcap.VdbTransmitter.Default, fdbTransmitter = repcap.FdbTransmitter.Default) \n
		Requires 'Mode > GBAS' (LAAS) header information. Sets the approach threshold crossing height. \n
			:param tch: float Range: 0 to 1638.35
			:param vdbTransmitter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Vdb')
			:param fdbTransmitter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fdb')"""
		param = Conversions.decimal_value_to_str(tch)
		vdbTransmitter_cmd_val = self._base.get_repcap_cmd_value(vdbTransmitter, repcap.VdbTransmitter)
		fdbTransmitter_cmd_val = self._base.get_repcap_cmd_value(fdbTransmitter, repcap.FdbTransmitter)
		self._core.io.write(f'SOURce<HwInstance>:BB:GBAS:VDB{vdbTransmitter_cmd_val}:MCONfig:FDB{fdbTransmitter_cmd_val}:ATCHeight {param}')

	def get(self, vdbTransmitter=repcap.VdbTransmitter.Default, fdbTransmitter=repcap.FdbTransmitter.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:GBAS:VDB<CH>:MCONfig:FDB<ST>:ATCHeight \n
		Snippet: value: float = driver.source.bb.gbas.vdb.mconfig.fdb.atcHeight.get(vdbTransmitter = repcap.VdbTransmitter.Default, fdbTransmitter = repcap.FdbTransmitter.Default) \n
		Requires 'Mode > GBAS' (LAAS) header information. Sets the approach threshold crossing height. \n
			:param vdbTransmitter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Vdb')
			:param fdbTransmitter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fdb')
			:return: tch: float Range: 0 to 1638.35"""
		vdbTransmitter_cmd_val = self._base.get_repcap_cmd_value(vdbTransmitter, repcap.VdbTransmitter)
		fdbTransmitter_cmd_val = self._base.get_repcap_cmd_value(fdbTransmitter, repcap.FdbTransmitter)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GBAS:VDB{vdbTransmitter_cmd_val}:MCONfig:FDB{fdbTransmitter_cmd_val}:ATCHeight?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ScTime:
	"""ScTime commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("scTime", core, parent)

	def set(self) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:TIME:STARt:SCTime \n
		Snippet: driver.source.bb.gnss.time.start.scTime.set() \n
		Applies date and time settings of the operating system to the simulation start time. \n
		"""
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:TIME:STARt:SCTime')

	def set_with_opc(self) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:TIME:STARt:SCTime \n
		Snippet: driver.source.bb.gnss.time.start.scTime.set_with_opc() \n
		Applies date and time settings of the operating system to the simulation start time. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsSmw.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:BB:GNSS:TIME:STARt:SCTime')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Osampling:
	"""Osampling commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("osampling", core, parent)

	def get_auto(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FILTer:OSAMpling:AUTO \n
		Snippet: value: bool = driver.source.bb.wlnn.filterPy.osampling.get_auto() \n
		No command help available \n
			:return: auto: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:WLNN:FILTer:OSAMpling:AUTO?')
		return Conversions.str_to_bool(response)

	def set_auto(self, auto: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FILTer:OSAMpling:AUTO \n
		Snippet: driver.source.bb.wlnn.filterPy.osampling.set_auto(auto = False) \n
		No command help available \n
			:param auto: No help available
		"""
		param = Conversions.bool_to_str(auto)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:FILTer:OSAMpling:AUTO {param}')

	def get_value(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FILTer:OSAMpling \n
		Snippet: value: int = driver.source.bb.wlnn.filterPy.osampling.get_value() \n
		No command help available \n
			:return: osampling: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:WLNN:FILTer:OSAMpling?')
		return Conversions.str_to_int(response)

	def set_value(self, osampling: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FILTer:OSAMpling \n
		Snippet: driver.source.bb.wlnn.filterPy.osampling.set_value(osampling = 1) \n
		No command help available \n
			:param osampling: No help available
		"""
		param = Conversions.decimal_value_to_str(osampling)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:FILTer:OSAMpling {param}')



from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Types import DataType
from ......Internal.Utilities import trim_str_response
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Data:
	"""Data commands group definition. 6 total commands, 1 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("data", core, parent)

	@property
	def hddStreaming(self):
		"""hddStreaming commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_hddStreaming'):
			from .HddStreaming import HddStreaming
			self._hddStreaming = HddStreaming(self._core, self._base)
		return self._hddStreaming

	def get_dselect(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:SIRius:DATA:DSELect \n
		Snippet: value: str = driver.source.bb.sirius.data.get_dselect() \n
		No command help available \n
			:return: dselect: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:SIRius:DATA:DSELect?')
		return trim_str_response(response)

	def set_dselect(self, dselect: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:SIRius:DATA:DSELect \n
		Snippet: driver.source.bb.sirius.data.set_dselect(dselect = '1') \n
		No command help available \n
			:param dselect: No help available
		"""
		param = Conversions.value_to_quoted_str(dselect)
		self._core.io.write(f'SOURce<HwInstance>:BB:SIRius:DATA:DSELect {param}')

	def get_edate(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:SIRius:DATA:EDATe \n
		Snippet: value: str = driver.source.bb.sirius.data.get_edate() \n
		No command help available \n
			:return: edate: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:SIRius:DATA:EDATe?')
		return trim_str_response(response)

	# noinspection PyTypeChecker
	class PatternStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Pattern: List[str]: No parameter help available
			- Bitcount: int: No parameter help available"""
		__meta_args_list = [
			ArgStruct('Pattern', DataType.RawStringList, None, False, True, 1),
			ArgStruct.scalar_int('Bitcount')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Pattern: List[str] = None
			self.Bitcount: int = None

	def get_pattern(self) -> PatternStruct:
		"""SCPI: [SOURce<HW>]:BB:SIRius:DATA:PATTern \n
		Snippet: value: PatternStruct = driver.source.bb.sirius.data.get_pattern() \n
		No command help available \n
			:return: structure: for return value, see the help for PatternStruct structure arguments.
		"""
		return self._core.io.query_struct('SOURce<HwInstance>:BB:SIRius:DATA:PATTern?', self.__class__.PatternStruct())

	def set_pattern(self, value: PatternStruct) -> None:
		"""SCPI: [SOURce<HW>]:BB:SIRius:DATA:PATTern \n
		Snippet: driver.source.bb.sirius.data.set_pattern(value = PatternStruct()) \n
		No command help available \n
			:param value: see the help for PatternStruct structure arguments.
		"""
		self._core.io.write_struct('SOURce<HwInstance>:BB:SIRius:DATA:PATTern', value)

	# noinspection PyTypeChecker
	def get_value(self) -> enums.DataSourceA:
		"""SCPI: [SOURce<HW>]:BB:SIRius:DATA \n
		Snippet: value: enums.DataSourceA = driver.source.bb.sirius.data.get_value() \n
		No command help available \n
			:return: data: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:SIRius:DATA?')
		return Conversions.str_to_scalar_enum(response, enums.DataSourceA)

	def set_value(self, data: enums.DataSourceA) -> None:
		"""SCPI: [SOURce<HW>]:BB:SIRius:DATA \n
		Snippet: driver.source.bb.sirius.data.set_value(data = enums.DataSourceA.DLISt) \n
		No command help available \n
			:param data: No help available
		"""
		param = Conversions.enum_scalar_to_str(data, enums.DataSourceA)
		self._core.io.write(f'SOURce<HwInstance>:BB:SIRius:DATA {param}')

	def clone(self) -> 'Data':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Data(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.RepeatedCapability import RepeatedCapability
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Svid:
	"""Svid commands group definition. 2 total commands, 2 Sub-groups, 0 group commands
	Repeated Capability: SatelliteSvid, default value after init: SatelliteSvid.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("svid", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_satelliteSvid_get', 'repcap_satelliteSvid_set', repcap.SatelliteSvid.Nr1)

	def repcap_satelliteSvid_set(self, enum_value: repcap.SatelliteSvid) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to SatelliteSvid.Default
		Default value after init: SatelliteSvid.Nr1"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_satelliteSvid_get(self) -> repcap.SatelliteSvid:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	@property
	def azimuth(self):
		"""azimuth commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_azimuth'):
			from .Azimuth import Azimuth
			self._azimuth = Azimuth(self._core, self._base)
		return self._azimuth

	@property
	def elevation(self):
		"""elevation commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_elevation'):
			from .Elevation import Elevation
			self._elevation = Elevation(self._core, self._base)
		return self._elevation

	def clone(self) -> 'Svid':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Svid(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Antenna:
	"""Antenna commands group definition. 27 total commands, 6 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("antenna", core, parent)

	@property
	def inverse(self):
		"""inverse commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_inverse'):
			from .Inverse import Inverse
			self._inverse = Inverse(self._core, self._base)
		return self._inverse

	@property
	def modeling(self):
		"""modeling commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_modeling'):
			from .Modeling import Modeling
			self._modeling = Modeling(self._core, self._base)
		return self._modeling

	@property
	def pattern(self):
		"""pattern commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_pattern'):
			from .Pattern import Pattern
			self._pattern = Pattern(self._core, self._base)
		return self._pattern

	@property
	def polarization(self):
		"""polarization commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_polarization'):
			from .Polarization import Polarization
			self._polarization = Polarization(self._core, self._base)
		return self._polarization

	@property
	def rx(self):
		"""rx commands group. 6 Sub-classes, 1 commands."""
		if not hasattr(self, '_rx'):
			from .Rx import Rx
			self._rx = Rx(self._core, self._base)
		return self._rx

	@property
	def tx(self):
		"""tx commands group. 6 Sub-classes, 1 commands."""
		if not hasattr(self, '_tx'):
			from .Tx import Tx
			self._tx = Tx(self._core, self._base)
		return self._tx

	def clone(self) -> 'Antenna':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Antenna(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group
